@@ -164,19 +164,19 @@ if(!is.null(x$R2)) { stats.df <- t(data.frame(sqrt(x$R2),x$R2,2*x$R2 -1))
 
  rownames(stats.df) <- c("Correlation of scores with factors  ","Multiple R square of scores with factors ","Minimum correlation of possible factor scores ")
          colnames(stats.df) <- colnames(x$loadings)
- }
+ } else {stats.df <- NULL}
  badFlag <- FALSE
  #however, if the solution is degenerate, don't print them
   
 
-   if( any(max(x$R2,na.rm=TRUE) > (1 + .Machine$double.eps) )) {badFlag <- TRUE
+   if( (is.null(x$R2)) || (any(max(x$R2,na.rm=TRUE) > (1 + .Machine$double.eps)) )) {badFlag <- TRUE
       if (!suppress.warnings) {
 	cat("\n WARNING, the factor score fit indices suggest that the solution is degenerate. Try a different method of factor extraction.\n")
 	 warning("the factor score fit indices suggest that the solution is degenerate\n")}
 	 } else {
 	
-	  cat("\nMeasures of factor score adequacy             \n")
-      print(round(stats.df,digits))
+	 if(!is.null(stats.df)) { cat("\nMeasures of factor score adequacy             \n")
+      print(round(stats.df,digits))}
 
 	if(!is.null(x$stats$R2) && !badFlag) {cat("\nMeasures of factor score adequacy             ",colnames(x$loadings)  )
 	cat("\nCorrelation of scores with factors           ",round(sqrt(x$R2),digits))
